pf-tools commit: r553 [parmelan-guest] - in /trunk/lib/PFTools: Conf.pm Net.pm Update.pm

parmelan-guest at users.alioth.debian.org parmelan-guest at users.alioth.debian.org
Thu Jan 17 16:54:54 UTC 2008


Author: parmelan-guest
Date: Thu Jan 17 16:54:52 2008
New Revision: 553

URL: http://svn.debian.org/wsvn/pf-tools/?sc=1&rev=553
Log:
utf8

Modified:
    trunk/lib/PFTools/Conf.pm
    trunk/lib/PFTools/Net.pm
    trunk/lib/PFTools/Update.pm

Modified: trunk/lib/PFTools/Conf.pm
URL: http://svn.debian.org/wsvn/pf-tools/trunk/lib/PFTools/Conf.pm?rev=553&op=diff
==============================================================================
--- trunk/lib/PFTools/Conf.pm (original)
+++ trunk/lib/PFTools/Conf.pm Thu Jan 17 16:54:52 2008
@@ -268,7 +268,7 @@
 sub Debug ($) {
     my (@msg) = @_;
 
-    # FIXME � faire une bonne fois pour toutes !
+    # FIXME à faire une bonne fois pour toutes !
     my $basename = ( split( '/', $0 ) )[-1];
     Log( $basename . ": DEBUG: ", @msg );
 }
@@ -555,9 +555,9 @@
 	Add_var( $V->{$esc1}, $quote, $val );
     }
     else {
-    	$var =~ s/\\\././g;
+	$var =~ s/\\\././g;
 	if ( defined( $V->{$var} ) ) {
-		print "Syntax error\n" ;
+#		print "Syntax error\n" ;
 	    return ($ERR_SYNTAX);
 	}
 	$V->{$var} = $val;

Modified: trunk/lib/PFTools/Net.pm
URL: http://svn.debian.org/wsvn/pf-tools/trunk/lib/PFTools/Net.pm?rev=553&op=diff
==============================================================================
--- trunk/lib/PFTools/Net.pm (original)
+++ trunk/lib/PFTools/Net.pm Thu Jan 17 16:54:52 2008
@@ -38,7 +38,6 @@
     Resolv
 
     Mk_dhcp
-    Mk_pxelinuxcfg
     Mk_interfaces
     Mk_zone
 );
@@ -47,7 +46,8 @@
 
 use Fcntl ':mode';
 use POSIX qw(ceil floor);
-use PFTools::Conf ;
+
+use PFTools::Conf;
 
 #use Data::Dumper;
 #$Data::Dumper::Sortkeys = 1;
@@ -497,7 +497,7 @@
 #	'5' => [ 'eth2:3', 'eth2:4' ]
 #    )
 #
-# FIXME le double foreach et double sort c'est douteux, mais c'�ait le moins invasif.
+# FIXME le double foreach et double sort c'est douteux, mais c'était le moins invasif.
 #
 
 #Debug "iforphan : "; warn Dumper(\%iforphan); Debug "ifmap : "; warn Dumper(\%ifmap);
@@ -964,7 +964,7 @@
 		$M->{'pxelinuxconf'} = $S->{'pxelinuxconf'}->{'default'};
 	    }
 
-            if ( defined( $S->{'pxetemplate'}->{$mnamindexnum} ) ) {
+	    if ( defined( $S->{'pxetemplate'}->{$mnamindexnum} ) ) {
 		$M->{'pxetemplate'} = $S->{'pxetemplate'}->{$mnamindexnum};
 	    }
 	    elsif ( defined( $S->{'pxetemplate'}->{'default'} ) ) {
@@ -985,8 +985,8 @@
 		$M->{'initrd'} = $S->{'initrd'}->{'default'};
 	    }
 	    else {
-
-# pour ne pas �re oblig�d'ajouter "initrd.default = initrd" �		# toutes les d�larations de serveurs dans private-network
+		# pour ne pas être obligé d'ajouter "initrd.default = initrd"
+		# à toutes les déclarations de serveurs dans private-network
 		$M->{'initrd'} = 'initrd';
 	    }
 
@@ -1621,86 +1621,6 @@
     close(FIC);
 }
 
-# sub Mk_pxelinuxcfg {
-#     my ( $template, $Z ) = @_;
-#     my $oldout;
-#     my $s;
-#     my $pxelinuxconfdir = dirname($template);
-#     my @templatecontent;
-# 
-#     open( PXETEMPLATE, "$template" )
-# 	|| die "impossible d'ouvrir " . $template . ": " . $!;
-#     @templatecontent = <PXETEMPLATE>;
-#     close(PXETEMPLATE);
-# 
-#     my $dhcpvlanregex
-# 	= '^([^.]+)\.('
-# 	. join( '|', @{ $Z->{'SOA'}->{'dhcpvlan'} } )
-# 	. ')(\.*)?$';
-# 
-#     foreach $s ( sort ( keys %{ $Z->{'SERVERS'}->{'BY_ADDR'} } ) ) {
-# 	my $m;
-# 	my $N = $Z->{'SERVERS'}->{'BY_ADDR'}->{$s};
-# 
-# 	foreach $m ( sort ( keys %{ $N->{'SRVLIST'} } ) ) {
-# 	    my $nam;
-# 	    my $M = $N->{'SRVLIST'}->{$m};
-# 
-# 	    foreach $nam ( sort ( keys %{ $M->{'zone'} } ) ) {
-# 		if ( $nam =~ /$dhcpvlanregex/ ) {
-# 		    my $nam2 = $1;
-# 
-# 		    #my $vlan2 = $2;
-# 		    if (   defined( $M->{'zone'}->{$nam}->{'ether'} )
-# 			&& defined( $M->{'filename'} )
-# 			&& defined( $M->{'pxefilename'} ) )
-# 		    {
-# 			if ( $M->{'filename'} ne 'pxelinux.0' ) {
-# 			    Warn( $ERR_SYNTAX,
-# 				      "Mk_pxelinuxconf[" 
-# 				    . $nam2
-# 				    . "]: pxefilename exists but filename is not pxelinux.0!"
-# 			    );
-# 			}
-# 			my $addr = Resolv( $nam . '.' . $Z->{'SOA'}->{'name'},
-# 			    $Z );
-# 			if ( defined $addr
-# 			    && $addr ne $nam . '.' . $Z->{'SOA'}->{'name'} )
-# 			{
-# 			    my $hexaddr = sprintf( '%02X%02X%02X%02X',
-# 				split( '\.', $addr ) );
-# 
-# 			    if ( -e $pxelinuxconfdir . "/" . $hexaddr ) {
-# 				unlink( $pxelinuxconfdir . "/" . $hexaddr );
-# 			    }
-# 
-# 			    open( PXELINUXCFG,
-# 				">" . $pxelinuxconfdir . "/" . $hexaddr )
-# 				|| die "impossible d'ecrire "
-# 				. $pxelinuxconfdir . "/"
-# 				. $hexaddr . ": "
-# 				. $!;
-# 			    my $temptemplatecontent
-# 				= join( "", @templatecontent );
-# 			    $temptemplatecontent
-# 				=~ s/%KERNEL%/$M->{pxefilename}/gs;
-# 			    $temptemplatecontent
-# 				=~ s/%INITRD%/$M->{initrd}/gs;
-# 			    my $ramdisk_size = Get_Ramdisk_size_from_Initrd(
-# 				$M->{'initrd'} );
-# 			    $temptemplatecontent
-# 				=~ s/%RAMDISK_SIZE%/$ramdisk_size/gs;
-# 			    my $cmdline = $M->{'cmdline'} || '';
-# 			    $temptemplatecontent =~ s/%CMDLINE%/$cmdline/gs;
-# 			    print PXELINUXCFG $temptemplatecontent;
-# 			    close(PXELINUXCFG);
-# 			}
-# 		    }
-# 		}
-# 	    }
-# 	}
-#     }
-# }
 
 sub Mk_zoneheader {
     my ( $fic_zone, $Z ) = @_;

Modified: trunk/lib/PFTools/Update.pm
URL: http://svn.debian.org/wsvn/pf-tools/trunk/lib/PFTools/Update.pm?rev=553&op=diff
==============================================================================
--- trunk/lib/PFTools/Update.pm (original)
+++ trunk/lib/PFTools/Update.pm Thu Jan 17 16:54:52 2008
@@ -4,7 +4,7 @@
 ##
 ##  Copyright (C) 2007 Christophe Caillet <tof at sitadelle.com>
 ##  Copyright (C) 2004-2007 Thomas Parmelan <tom+pf-tools at ankh.fr.EU.org>
-##  Copyright (C) 2004 Gon�ri Le Bouder <goneri at sitadelle.com>
+##  Copyright (C) 2004 Gonéri Le Bouder <goneri at sitadelle.com>
 ##  Copyright (C) 2003-2005 Damien Clermonte <damien at sitadelle.com>
 ##  Copyright (C) 2001-2003 Olivier Molteni <olivier at molteni.net>
 ##
@@ -1864,7 +1864,7 @@
 
 }
 
-# Si une branche a ��pass�en para, elle est retourn� sinon undef.
+# Si une branche a été passée en para, elle est retournée sinon undef.
 sub GetBrancheFromCmdLine {
 
     my $branche;
@@ -1877,16 +1877,16 @@
 
 }
 
 # MAJ le CVS, peut mettre une branche pr�ise a jour, en passant le nom
 # de cette branche en param�re
 sub CVS_update (;$$) {
     my ( $branche, $options ) = @_;
 
     if ($branche) {
 	if ( defined $CVS_COMMAND ) {
 	    print
-		"Attention : j'ignore la variable \$CVS_COMMAND d�inie dans "
-		. "`$PFTOOLSCONF' car j'utilise une branche pr�ise ($branche)\n"
+		"Attention : j'ignore la variable \$CVS_COMMAND définie dans "
+		. "`$PFTOOLSCONF' car j'utilise une branche précise ($branche)\n"
 		if defined $options and $options->{verbose};
 	    undef $CVS_COMMAND;
 	}
@@ -1877,16 +1877,16 @@
 }
 
-# MAJ le CVS, peut mettre une branche pr�ise a jour, en passant le nom
-# de cette branche en param�re
+# MAJ le CVS, peut mettre une branche précise à jour, en passant le nom
+# de cette branche en paramètre
 sub CVS_update (;$$) {
     my ( $branche, $options ) = @_;




More information about the pf-tools-commits mailing list